'use strict';

import React from 'react';
import PropTypes from 'prop-types';
import Radium from 'radium';
import { VelocityComponent } from 'velocity-react';

const Loading = ({ style }) => {
  return <div style={style}>loading...</div>;
};
Loading.propTypes = {
  style: PropTypes.object
};

const Toggle = ({ style }) => {
  const { height, width } = style;
  const midHeight = height * 0.5;
  const points = `0,0 0,${height} ${width},${midHeight}`;

  return (
    <div style={style.base}>
      <div style={style.wrapper}>
        <svg height={height} width={width}>
          <polygon points={points}
            style={style.arrow} />
        </svg>
      </div>
    </div>
  );
};
Toggle.propTypes = {
  style: PropTypes.object
};

const Header = ({ node, style, onClick, onContextMenu }) => {
  let iconType = 'list';
  if (node.type === 'directory') iconType = 'folder-o';
  if (node.type === 'page') iconType = 'file-text';
  if (node.type === 'app') iconType = 'sitemap';

  if (node.active) {
    iconType = iconType + ' toggledIcon';
  }
  const iconClass = `fa fa-${iconType} treeIcon`;
  const iconStyle = { marginRight: '5px' };
  return (
    <div onClick={onClick} onContextMenu={onContextMenu} style={style.base}>
      <div style={style.title}>
        <i className={iconClass} style={iconStyle} />

        {node.name}
      </div>
    </div>
  );
};
Header.propTypes = {
  style: PropTypes.object,
  node: PropTypes.object.isRequired
};

@Radium
class Container extends React.Component {
  render() {
    const {
      style, decorators, terminal, onClick, onToggle, node, customProps, onContextMenu
    } = this.props;

    return (
      <div onClick={onToggle}
        ref={ref => this.clickableRef = ref}
        style={style.container}>
        {!terminal ? this.renderToggle() : null}

        <decorators.Header
          node={node}
          style={style.header}
          onClick={onClick}
          onContextMenu={onContextMenu}
        />
      </div>
    );
  }

  renderToggle() {
    const { animations } = this.props;

    if (!animations) {
      return this.renderToggleDecorator();
    }

    return (
      <VelocityComponent animation={animations.toggle.animation}
        duration={animations.toggle.duration}
        ref={ref => this.velocityRef = ref}>
        {this.renderToggleDecorator()}
      </VelocityComponent>
    );
  }

  renderToggleDecorator() {
    const { style, decorators } = this.props;

    return <decorators.Toggle style={style.toggle} />;
  }
}
Container.propTypes = {
  style: PropTypes.object.isRequired,
  decorators: PropTypes.object.isRequired,
  terminal: PropTypes.bool.isRequired,
  onClick: PropTypes.func.isRequired,
  animations: PropTypes.oneOfType([
    PropTypes.object,
    PropTypes.bool
  ]).isRequired,
  node: PropTypes.object.isRequired
};

export default {
  Loading,
  Toggle,
  Header,
  Container
};
